@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: NBNodeShapeComputer.cpp 18756 2015-08-31 19:16:33Z behrisch $
+/// @version $Id: NBNodeShapeComputer.cpp 21851 2016-10-31 12:20:12Z behrisch $
 ///
 // This class computes shapes of junctions
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -47,6 +47,8 @@
 #include <foreign/nvwa/debug_new.h>
 #endif // CHECK_MEMORY_LEAKS
 
+//#define DEBUG_NODE_SHAPE
+#define DEBUGCOND (myNode.getID() == "disabled")
 
 // ===========================================================================
 // method definitions
@@ -112,25 +114,23 @@ NBNodeShapeComputer::compute() {
 
 void
 computeSameEnd(PositionVector& l1, PositionVector& l2) {
-    Line sub(l1.lineAt(0).getPositionAtDistance2D(100), l1[1]);
-    Line tmp(sub);
-    tmp.rotateAtP1(M_PI / 2);
-    tmp.extrapolateBy2D(100);
-    if (l1.intersects(tmp.p1(), tmp.p2())) {
-        SUMOReal offset1 = l1.intersectsAtLengths2D(tmp)[0];
-        Line tl1 = Line(
-                       l1.lineAt(0).getPositionAtDistance2D(offset1),
-                       l1[1]);
-        tl1.extrapolateBy2D(100);
-        l1.replaceAt(0, tl1.p1());
-    }
-    if (l2.intersects(tmp.p1(), tmp.p2())) {
-        SUMOReal offset2 = l2.intersectsAtLengths2D(tmp)[0];
-        Line tl2 = Line(
-                       l2.lineAt(0).getPositionAtDistance2D(offset2),
-                       l2[1]);
-        tl2.extrapolateBy2D(100);
-        l2.replaceAt(0, tl2.p1());
+    assert(l1[0].distanceTo2D(l1[1]) >= 100.);
+    assert(l2[0].distanceTo2D(l2[1]) >= 100.);
+    PositionVector tmp;
+    tmp.push_back(PositionVector::positionAtOffset2D(l1[0], l1[1], 100));
+    tmp.push_back(l1[1]);
+    tmp[1].sub(tmp[0]);
+    tmp[1].set(-tmp[1].y(), tmp[1].x());
+    tmp[1].add(tmp[0]);
+    tmp.extrapolate2D(100);
+    if (l2.intersects(tmp[0], tmp[1])) {
+        const SUMOReal offset = l2.intersectsAtLengths2D(tmp)[0];
+        if (l2.length2D() - offset > POSITION_EPS) {
+            PositionVector tl2 = l2.getSubpart2D(offset, l2.length2D());
+            tl2.extrapolate2D(100);
+            l2.erase(l2.begin(), l2.begin() + (l2.size() - tl2.size()));
+            l2[0] = tl2[0];
+        }
     }
 }
 
@@ -142,8 +142,18 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
         return PositionVector();
     }
     // magic values
-    const SUMOReal radius = (myNode.getRadius() == NBNode::UNSPECIFIED_RADIUS ? NBNode::DEFAULT_RADIUS : myNode.getRadius());
+    const bool defaultRadius = myNode.getRadius() == NBNode::UNSPECIFIED_RADIUS;
+    const SUMOReal radius = (defaultRadius ? OptionsCont::getOptions().getFloat("default.junctions.radius") : myNode.getRadius());
     const int cornerDetail = OptionsCont::getOptions().getInt("junctions.corner-detail");
+    const SUMOReal sCurveStretch = OptionsCont::getOptions().getFloat("junctions.scurve-stretch");
+    const bool rectangularCut = OptionsCont::getOptions().getBool("rectangular-lane-cut");
+    const bool openDriveOutput = OptionsCont::getOptions().isSet("opendrive-output");
+
+#ifdef DEBUG_NODE_SHAPE
+    if (DEBUGCOND) {
+        std::cout << "\ncomputeNodeShapeDefault node " << myNode.getID() << " simple=" << simpleContinuation << " radius=" << radius << "\n";
+    }
+#endif
 
     // initialise
     EdgeVector::const_iterator i;
@@ -153,17 +163,10 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
     GeomsMap geomsCCW;
     // the clockwise boundary of the edge regarding possible same-direction edges
     GeomsMap geomsCW;
-    // store relationships
-    std::map<NBEdge*, NBEdge*> ccwBoundary;
-    std::map<NBEdge*, NBEdge*> cwBoundary;
-    for (i = myNode.myAllEdges.begin(); i != myNode.myAllEdges.end(); i++) {
-        cwBoundary[*i] = *i;
-        ccwBoundary[*i] = *i;
-    }
     // check which edges are parallel
     joinSameDirectionEdges(same, geomsCCW, geomsCW);
     // compute unique direction list
-    EdgeVector newAll = computeUniqueDirectionList(same, geomsCCW, geomsCW, ccwBoundary, cwBoundary);
+    EdgeVector newAll = computeUniqueDirectionList(same, geomsCCW, geomsCW);
     // if we have only two "directions", let's not compute the geometry using this method
     if (newAll.size() < 2) {
         return PositionVector();
@@ -202,15 +205,27 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
                 p = geomsCCW[*ccwi][0];
                 p.add(geomsCW[*ccwi][0]);
                 p.mul(0.5);
+#ifdef DEBUG_NODE_SHAPE
+                if (DEBUGCOND) {
+                    std::cout << " extended: p=" << p << " angle=" << (ccad - cad) << "\n";
+                }
+#endif
             } else {
                 p = geomsCCW[*ccwi][0];
                 p.add(geomsCW[*ccwi][0]);
                 p.add(geomsCCW[*i][0]);
                 p.add(geomsCW[*i][0]);
                 p.mul(0.25);
+#ifdef DEBUG_NODE_SHAPE
+                if (DEBUGCOND) {
+                    std::cout << " unextended: p=" << p << " angle=" << (ccad - cad) << "\n";
+                }
+#endif
             }
             // ... compute the distance to this point ...
-            SUMOReal dist = geomsCCW[*i].nearest_offset_to_point2D(p);
+            SUMOReal dist = MAX2(
+                                geomsCCW[*i].nearest_offset_to_point2D(p),
+                                geomsCW[*i].nearest_offset_to_point2D(p));
             if (dist < 0) {
                 // ok, we have the problem that even the extrapolated geometry
                 //  does not reach the point
@@ -231,14 +246,26 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
                 // the distance is now = zero (the point we have appended)
                 distances[*i] = 100;
                 myExtended[*i] = true;
+#ifdef DEBUG_NODE_SHAPE
+                if (DEBUGCOND) {
+                    std::cout << " extending (dist=" << dist << ")\n";
+                }
+#endif
             } else {
                 if (!simpleContinuation) {
-                    // since there are only two (almost parallel) directions, the
-                    // concept of a turning radius does not quite fit. Instead we need
-                    // to enlarge the intersection to accomodate the change in
-                    // the number of lanes
-                    // @todo: make this independently configurable
                     dist += radius;
+                } else {
+                    // if the angles change, junction should have some size to avoid degenerate shape
+                    SUMOReal radius2 = fabs(ccad - cad) * (*i)->getNumLanes();
+                    if (radius2 > NUMERICAL_EPS || openDriveOutput) {
+                        radius2 = MAX2((SUMOReal)0.15, radius2);
+                    }
+                    dist += radius2;
+#ifdef DEBUG_NODE_SHAPE
+                    if (DEBUGCOND) {
+                        std::cout << " using radius=" << fabs(ccad - cad) * (*i)->getNumLanes() << " ccad=" << ccad << " cad=" << cad << "\n";
+                    }
+#endif
                 }
                 distances[*i] = dist;
             }
@@ -255,27 +282,57 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
             const PositionVector& neighGeom = ccwCloser ? geomsCW[*ccwi] : geomsCCW[*cwi];
             // the border of the far neighbor
             const PositionVector& neighGeom2 = ccwCloser ? geomsCCW[*cwi] : geomsCW[*ccwi];
+#ifdef DEBUG_NODE_SHAPE
+            if (DEBUGCOND) {
+                std::cout << " i=" << (*i)->getID() << " neigh=" << (*ccwi)->getID() << " neigh2=" << (*cwi)->getID() << "\n";
+            }
+#endif
             if (!simpleContinuation) {
                 if (currGeom.intersects(neighGeom)) {
                     distances[*i] = radius + closestIntersection(currGeom, neighGeom, 100);
+#ifdef DEBUG_NODE_SHAPE
+                    if (DEBUGCOND) {
+                        std::cout << "   neigh intersects dist=" << distances[*i] << " currGeom=" << currGeom << " neighGeom=" << neighGeom << "\n";
+                    }
+#endif
                     if (*cwi != *ccwi && currGeom2.intersects(neighGeom2)) {
                         const SUMOReal farAngleDist = ccwCloser ? cad : ccad;
                         SUMOReal a1 = distances[*i];
                         SUMOReal a2 = radius + closestIntersection(currGeom2, neighGeom2, 100);
+#ifdef DEBUG_NODE_SHAPE
+                        if (DEBUGCOND) {
+                            std::cout << "      neigh2 also intersects a1=" << a1 << " a2=" << a2 << " ccad=" << RAD2DEG(ccad) << " cad=" << RAD2DEG(cad) << " dist[cwi]=" << distances[*cwi] << " dist[ccwi]=" << distances[*ccwi] << " farAngleDist=" << RAD2DEG(farAngleDist) << " currGeom2=" << currGeom2 << " neighGeom2=" << neighGeom2 << "\n";
+                        }
+#endif
                         if (ccad > DEG2RAD(90. + 45.) && cad > DEG2RAD(90. + 45.)) {
                             SUMOReal mmin = MIN2(distances[*cwi], distances[*ccwi]);
-                            if (mmin > 100) {
+                            if (mmin > 100 && mmin < 205) {
                                 distances[*i] = (SUMOReal) 5. + (SUMOReal) 100. - (SUMOReal)(mmin - 100); //100 + 1.5;
                             }
                         } else if (fabs(a2 - a1) < 10 || farAngleDist < DEG2RAD(135)) {
                             distances[*i] = MAX2(a1, a2);
                         }
+#ifdef DEBUG_NODE_SHAPE
+                        if (DEBUGCOND) {
+                            std::cout << "   a1=" << a1 << " a2=" << a2 << " dist=" << distances[*i] << "\n";
+                        }
+#endif
                     }
                 } else {
                     if (*cwi != *ccwi && currGeom2.intersects(neighGeom2)) {
                         distances[*i] = radius + currGeom2.intersectsAtLengths2D(neighGeom2)[0];
+#ifdef DEBUG_NODE_SHAPE
+                        if (DEBUGCOND) {
+                            std::cout << "   neigh2 intersects dist=" << distances[*i] << " currGeom2=" << currGeom2 << " neighGeom2=" << neighGeom2 << "\n";
+                        }
+#endif
                     } else {
                         distances[*i] = 100 + radius;
+#ifdef DEBUG_NODE_SHAPE
+                        if (DEBUGCOND) {
+                            std::cout << "   no intersects dist=" << distances[*i]  << " currGeom=" << currGeom << " neighGeom=" << neighGeom << " currGeom2=" << currGeom2 << " neighGeom2=" << neighGeom2 << "\n";
+                        }
+#endif
                     }
                 }
             } else {
@@ -286,6 +343,20 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
                 }
             }
         }
+        if (defaultRadius && sCurveStretch > 0) {
+            SUMOReal sCurveWidth = myNode.getDisplacementError();
+            if (sCurveWidth > 0) {
+                const SUMOReal sCurveRadius = radius + sCurveWidth / SUMO_const_laneWidth * sCurveStretch * pow((*i)->getSpeed(), 2 + sCurveStretch) / 1000;
+                distances[*i] = MAX2(distances[*i], 100 + sCurveRadius);
+                // @dirty: update radius so it is exported to the network
+                const_cast<NBNode&>(myNode).setRadius(sCurveRadius);
+#ifdef DEBUG_NODE_SHAPE
+                if (DEBUGCOND) {
+                    std::cout << "   stretching junction: sCurveWidth=" << sCurveWidth << " sCurveRadius=" << sCurveRadius << " dist=" << distances[*i]  << "\n";
+                }
+#endif
+            }
+        }
     }
 
     for (i = newAll.begin(); i != newAll.end(); ++i) {
@@ -299,17 +370,13 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
     PositionVector ret;
     for (i = newAll.begin(); i != newAll.end(); ++i) {
         const PositionVector& ccwBound = geomsCCW[*i];
-        SUMOReal len = ccwBound.length();
         SUMOReal offset = distances[*i];
         if (offset == -1) {
+            WRITE_WARNING("Fixing offset for edge '" + (*i)->getID() + "' at node '" + myNode.getID() + ".");
             offset = (SUMOReal) - .1;
         }
         Position p;
-        if (len >= offset) {
-            p = ccwBound.positionAtOffset2D(offset);
-        } else {
-            p = ccwBound.positionAtOffset2D(len);
-        }
+        p = ccwBound.positionAtOffset2D(offset);
         p.set(p.x(), p.y(), myNode.getPosition().z());
         if (i != newAll.begin()) {
             ret.append(getSmoothCorner(geomsCW[*(i - 1)].reverse(), ccwBound, ret[-1], p, cornerDetail));
@@ -317,14 +384,20 @@ NBNodeShapeComputer::computeNodeShapeDefault(bool simpleContinuation) {
         ret.push_back_noDoublePos(p);
         //
         const PositionVector& cwBound = geomsCW[*i];
-        len = cwBound.length();
-        if (len >= offset) {
-            p = cwBound.positionAtOffset2D(offset);
-        } else {
-            p = cwBound.positionAtOffset2D(len);
-        }
+        p = cwBound.positionAtOffset2D(offset);
         p.set(p.x(), p.y(), myNode.getPosition().z());
         ret.push_back_noDoublePos(p);
+#ifdef DEBUG_NODE_SHAPE
+        if (DEBUGCOND) {
+            std::cout << "   build stopLine for i=" << (*i)->getID() << " offset=" << offset << " ccwBound=" <<  ccwBound << " cwBound=" << cwBound << "\n";
+        }
+#endif
+        if (rectangularCut) {
+            (*i)->setNodeBorder(&myNode, p);
+            for (std::set<NBEdge*>::iterator k = same[*i].begin(); k != same[*i].end(); ++k) {
+                (*k)->setNodeBorder(&myNode, p);
+            }
+        }
     }
     // final curve segment
     ret.append(getSmoothCorner(geomsCW[*(newAll.end() - 1)], geomsCCW[*newAll.begin()], ret[-1], ret[0], cornerDetail));
@@ -355,8 +428,8 @@ NBNodeShapeComputer::getSmoothCorner(PositionVector begShape, PositionVector end
         endShape[0] = endPoint;
         PositionVector curve = myNode.computeSmoothShape(begShape, endShape, cornerDetail + 2, false, 25, 25);
         if (curve.size() > 2) {
-            curve.eraseAt(0);
-            curve.eraseAt(-1);
+            curve.erase(curve.begin());
+            curve.pop_back();
             ret = curve;
         }
     }
@@ -388,13 +461,8 @@ NBNodeShapeComputer::joinSameDirectionEdges(std::map<NBEdge*, std::set<NBEdge*>
             myNode.hasIncoming(*i)
             ? (*i)->getCCWBoundaryLine(myNode)
             : (*i)->getCWBoundaryLine(myNode);
-        Line l1 = g1.lineAt(0);
-        Line tmp = geomsCCW[*i].lineAt(0);
-        tmp.extrapolateBy2D(100);
-        geomsCCW[*i].replaceAt(0, tmp.p1());
-        tmp = geomsCW[*i].lineAt(0);
-        tmp.extrapolateBy2D(100);
-        geomsCW[*i].replaceAt(0, tmp.p1());
+        geomsCCW[*i].extrapolate2D(100, true);
+        geomsCW[*i].extrapolate2D(100, true);
         //
         for (j = i + 1; j != myNode.myAllEdges.end(); j++) {
             geomsCCW[*j] = (*j)->getCCWBoundaryLine(myNode);
@@ -403,13 +471,8 @@ NBNodeShapeComputer::joinSameDirectionEdges(std::map<NBEdge*, std::set<NBEdge*>
                 myNode.hasIncoming(*j)
                 ? (*j)->getCCWBoundaryLine(myNode)
                 : (*j)->getCWBoundaryLine(myNode);
-            Line l2 = g2.lineAt(0);
-            tmp = geomsCCW[*j].lineAt(0);
-            tmp.extrapolateBy2D(100);
-            geomsCCW[*j].replaceAt(0, tmp.p1());
-            tmp = geomsCW[*j].lineAt(0);
-            tmp.extrapolateBy2D(100);
-            geomsCW[*j].replaceAt(0, tmp.p1());
+            geomsCCW[*j].extrapolate2D(100, true);
+            geomsCW[*j].extrapolate2D(100, true);
         }
     }
     // compute same (edges where an intersection doesn't work well
@@ -417,32 +480,32 @@ NBNodeShapeComputer::joinSameDirectionEdges(std::map<NBEdge*, std::set<NBEdge*>
     // distance to look ahead for a misleading angle
     const SUMOReal angleChangeLookahead = 35;
     EdgeSet foundOpposite;
-    for (i = myNode.myAllEdges.begin(); i != myNode.myAllEdges.end() - 1; i++) {
-        EdgeVector::const_iterator j = i + 1;
-        if (j == myNode.myAllEdges.end()) {
+    for (i = myNode.myAllEdges.begin(); i != myNode.myAllEdges.end(); i++) {
+        EdgeVector::const_iterator j;
+        if (i == myNode.myAllEdges.end() - 1) {
             j = myNode.myAllEdges.begin();
+        } else {
+            j = i + 1;
         }
         const bool incoming = (*i)->getToNode() == &myNode;
         const bool incoming2 = (*j)->getToNode() == &myNode;
         const Position positionAtNode = (*i)->getGeometry()[incoming ? -1 : 0];
         const Position positionAtNode2 = (*j)->getGeometry()[incoming2 ? -1 : 0];
-        PositionVector g1 = incoming ? (*i)->getCCWBoundaryLine(myNode) : (*i)->getCWBoundaryLine(myNode);
-        PositionVector g2 = incoming ? (*j)->getCCWBoundaryLine(myNode) : (*j)->getCWBoundaryLine(myNode);
-        Line l1 = g1.lineAt(0);
-        Line l2 = g2.lineAt(0);
-        const SUMOReal angle1further = (g1.size() > 2 && l1.length2D() < angleChangeLookahead ?
-                                        g1.lineAt(1).atan2DegreeAngle() : l1.atan2DegreeAngle());
-        const SUMOReal angle2further = (g2.size() > 2 && l2.length2D() < angleChangeLookahead ?
-                                        g2.lineAt(1).atan2DegreeAngle() : l2.atan2DegreeAngle());
-        const SUMOReal angleDiff = NBHelpers::relAngle(l1.atan2DegreeAngle(), l2.atan2DegreeAngle());
-        const SUMOReal angleDiffFurther = NBHelpers::relAngle(angle1further, angle2further);
+        const PositionVector g1 = incoming ? (*i)->getCCWBoundaryLine(myNode) : (*i)->getCWBoundaryLine(myNode);
+        const PositionVector g2 = incoming ? (*j)->getCCWBoundaryLine(myNode) : (*j)->getCWBoundaryLine(myNode);
+        const SUMOReal angle1further = (g1.size() > 2 && g1[0].distanceTo2D(g1[1]) < angleChangeLookahead ?
+                                        g1.angleAt2D(1) : g1.angleAt2D(0));
+        const SUMOReal angle2further = (g2.size() > 2 && g2[0].distanceTo2D(g2[1]) < angleChangeLookahead ?
+                                        g2.angleAt2D(1) : g2.angleAt2D(0));
+        const SUMOReal angleDiff = GeomHelper::angleDiff(g1.angleAt2D(0), g2.angleAt2D(0));
+        const SUMOReal angleDiffFurther = GeomHelper::angleDiff(angle1further, angle2further);
         const bool ambiguousGeometry = ((angleDiff > 0 && angleDiffFurther < 0) || (angleDiff < 0 && angleDiffFurther > 0));
         const bool differentDirs = (incoming != incoming2);
         //if (ambiguousGeometry) {
         //    @todo: this warning would be helpful in many cases. However, if angle and angleFurther jump between 179 and -179 it is misleading
-        //    WRITE_WARNING("Ambigous angles at node '" + myNode.getID() + "' for edges '" + (*i)->getID() + "' and '" + (*j)->getID() + "'.");
+        //    WRITE_WARNING("Ambigous angles at junction '" + myNode.getID() + "' for edges '" + (*i)->getID() + "' and '" + (*j)->getID() + "'.");
         //}
-        if (fabs(angleDiff) < 20) {
+        if (fabs(angleDiff) < DEG2RAD(20)) {
             const bool isOpposite = differentDirs && foundOpposite.count(*i) == 0;
             if (isOpposite) {
                 foundOpposite.insert(*i);
@@ -464,6 +527,11 @@ NBNodeShapeComputer::joinSameDirectionEdges(std::map<NBEdge*, std::set<NBEdge*>
                 }
                 same[*i].insert(*j);
                 same[*j].insert(*i);
+#ifdef DEBUG_NODE_SHAPE
+                if (DEBUGCOND) {
+                    std::cout << "   joinedSameDirectionEdges " << (*i)->getID() << "   " << (*j)->getID() << " isOpposite=" << isOpposite << " ambiguousGeometry=" << ambiguousGeometry << "\n";
+                }
+#endif
             }
         }
     }
@@ -510,40 +578,34 @@ EdgeVector
 NBNodeShapeComputer::computeUniqueDirectionList(
     std::map<NBEdge*, std::set<NBEdge*> >& same,
     GeomsMap& geomsCCW,
-    GeomsMap& geomsCW,
-    std::map<NBEdge*, NBEdge*>& ccwBoundary,
-    std::map<NBEdge*, NBEdge*>& cwBoundary) {
+    GeomsMap& geomsCW) {
+    // store relationships
     EdgeVector newAll = myNode.myAllEdges;
-    std::set<NBEdge*>::const_iterator j;
-    EdgeVector::iterator i2;
-    std::map<NBEdge*, EdgeVector >::iterator k;
     bool changed = true;
     while (changed) {
         changed = false;
-        for (i2 = newAll.begin(); !changed && i2 != newAll.end();) {
+        for (EdgeVector::iterator i2 = newAll.begin(); i2 != newAll.end(); ++i2) {
             std::set<NBEdge*> other = same[*i2];
-            for (j = other.begin(); j != other.end(); ++j) {
+            for (std::set<NBEdge*>::const_iterator j = other.begin(); j != other.end(); ++j) {
                 EdgeVector::iterator k = find(newAll.begin(), newAll.end(), *j);
                 if (k != newAll.end()) {
                     if (myNode.hasIncoming(*i2)) {
-                        if (myNode.hasIncoming(*j)) {} else {
+                        if (!myNode.hasIncoming(*j)) {
                             geomsCW[*i2] = geomsCW[*j];
-                            cwBoundary[*i2] = *j;
                             computeSameEnd(geomsCW[*i2], geomsCCW[*i2]);
                         }
                     } else {
                         if (myNode.hasIncoming(*j)) {
-                            ccwBoundary[*i2] = *j;
                             geomsCCW[*i2] = geomsCCW[*j];
                             computeSameEnd(geomsCW[*i2], geomsCCW[*i2]);
-                        } else {}
+                        }
                     }
                     newAll.erase(k);
                     changed = true;
                 }
             }
-            if (!changed) {
-                ++i2;
+            if (changed) {
+                break;
             }
         }
     }
@@ -572,59 +634,48 @@ NBNodeShapeComputer::initNeighbors(const EdgeVector& edges, const EdgeVector::co
         ccwi--;
     }
 
-    const SUMOReal angleCurCCW = geomsCCW[*current].lineAt(0).atan2PositiveAngle();
-    const SUMOReal angleCurCW = geomsCW[*current].lineAt(0).atan2PositiveAngle();
-    const SUMOReal angleCCW = geomsCW[*ccwi].lineAt(0).atan2PositiveAngle();
-    const SUMOReal angleCW = geomsCCW[*cwi].lineAt(0).atan2PositiveAngle();
-    if (angleCurCCW > angleCCW) {
-        ccad = angleCurCCW - angleCCW;
-    } else {
-        ccad = twoPI - (angleCCW - angleCurCCW);
-    }
-
-    if (angleCurCW > angleCW) {
-        cad = twoPI - (angleCurCW - angleCW);
-    } else {
-        cad = angleCW - angleCurCW;
-    }
-
-    if (ccad < 0) {
+    const SUMOReal angleCurCCW = geomsCCW[*current].angleAt2D(0);
+    const SUMOReal angleCurCW = geomsCW[*current].angleAt2D(0);
+    const SUMOReal angleCCW = geomsCW[*ccwi].angleAt2D(0);
+    const SUMOReal angleCW = geomsCCW[*cwi].angleAt2D(0);
+    ccad = angleCCW - angleCurCCW;
+    while (ccad < 0.) {
         ccad += twoPI;
     }
-    if (ccad > twoPI) {
-        ccad -= twoPI;
-    }
-    if (cad < 0) {
+    cad = angleCurCW - angleCW;
+    while (cad < 0.) {
         cad += twoPI;
     }
-    if (cad > twoPI) {
-        cad -= twoPI;
-    }
 }
 
 
 
 PositionVector
 NBNodeShapeComputer::computeNodeShapeSmall() {
+#ifdef DEBUG_NODE_SHAPE
+    if (DEBUGCOND) {
+        std::cout << "computeNodeShapeSmall node=" << myNode.getID() << "\n";
+    }
+#endif
     PositionVector ret;
     EdgeVector::const_iterator i;
     for (i = myNode.myAllEdges.begin(); i != myNode.myAllEdges.end(); i++) {
         // compute crossing with normal
-        Line edgebound1 = (*i)->getCCWBoundaryLine(myNode).lineAt(0);
-        Line edgebound2 = (*i)->getCWBoundaryLine(myNode).lineAt(0);
-        Line cross(edgebound1);
-        cross.rotateAtP1(M_PI / 2.);
-        cross.add(myNode.getPosition() - cross.p1());
-        cross.extrapolateBy2D(500);
-        edgebound1.extrapolateBy2D(500);
-        edgebound2.extrapolateBy2D(500);
+        PositionVector edgebound1 = (*i)->getCCWBoundaryLine(myNode).getSubpartByIndex(0, 2);
+        PositionVector edgebound2 = (*i)->getCWBoundaryLine(myNode).getSubpartByIndex(0, 2);
+        Position delta = edgebound1[1] - edgebound1[0];
+        delta.set(-delta.y(), delta.x()); // rotate 90 degrees
+        PositionVector cross(myNode.getPosition(), myNode.getPosition() + delta);
+        cross.extrapolate2D(500);
+        edgebound1.extrapolate2D(500);
+        edgebound2.extrapolate2D(500);
         if (cross.intersects(edgebound1)) {
-            Position np = cross.intersectsAt(edgebound1);
+            Position np = cross.intersectionPosition2D(edgebound1);
             np.set(np.x(), np.y(), myNode.getPosition().z());
             ret.push_back_noDoublePos(np);
         }
         if (cross.intersects(edgebound2)) {
-            Position np = cross.intersectsAt(edgebound2);
+            Position np = cross.intersectionPosition2D(edgebound2);
             np.set(np.x(), np.y(), myNode.getPosition().z());
             ret.push_back_noDoublePos(np);
         }
