@@ -4,7 +4,7 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: NIVissimConnectionCluster.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NIVissimConnectionCluster.cpp 21202 2016-07-19 13:40:35Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
@@ -90,9 +90,9 @@ NIVissimConnectionCluster::NodeSubCluster::add(const NIVissimConnectionCluster::
 }
 
 
-size_t
+int
 NIVissimConnectionCluster::NodeSubCluster::size() const {
-    return myConnections.size();
+    return (int)myConnections.size();
 }
 
 
@@ -224,7 +224,7 @@ NIVissimConnectionCluster::joinBySameEdges(SUMOReal offset) {
     //  the lists of incoming and outgoing edges and incrementally building the nodes
     //  regarding this information
     std::vector<NIVissimConnectionCluster*> joinAble;
-    size_t pos = 0;
+    int pos = 0;
     ContType::iterator i = myClusters.begin();
     // step1 - faster but no complete
     while (i != myClusters.end()) {
@@ -547,9 +547,9 @@ NIVissimConnectionCluster::hasNodeCluster() const {
 }
 
 
-size_t
+int
 NIVissimConnectionCluster::dictSize() {
-    return myClusters.size();
+    return (int)myClusters.size();
 }
 
 
@@ -634,7 +634,7 @@ NIVissimConnectionCluster::getPositionForEdge(int edgeid) const {
     // return the middle of the connections when there are any
     if (myConnections.size() != 0) {
         SUMOReal sum = 0;
-        size_t part = 0;
+        int part = 0;
         std::vector<int>::const_iterator i;
         for (i = myConnections.begin(); i != myConnections.end(); i++) {
             NIVissimConnection* c = NIVissimConnection::dictionary(*i);
