@@ -3,7 +3,7 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    19.01.2012
-/// @version $Id: GUIOSGView.cpp 20768 2016-05-20 08:38:44Z behrisch $
+/// @version $Id: GUIOSGView.cpp 21851 2016-10-31 12:20:12Z behrisch $
 ///
 // An OSG-based 3D view on the simulation
 /****************************************************************************/
@@ -267,6 +267,16 @@ GUIOSGView::buildViewToolBars(GUIGlChildWindow& v) {
 void
 GUIOSGView::recenterView() {
     stopTrack();
+    Position center = myGrid->getCenter();
+    osg::Vec3d lookFromOSG, lookAtOSG, up;
+    myViewer->getCameraManipulator()->getHomePosition(lookFromOSG, lookAtOSG, up);
+    lookFromOSG[0] = center.x();
+    lookFromOSG[1] = center.y();
+    lookFromOSG[2] = myChanger->zoom2ZPos(100);
+    lookAtOSG[0] = center.x();
+    lookAtOSG[1] = center.y();
+    lookAtOSG[2] = 0;
+    myViewer->getCameraManipulator()->setHomePosition(lookFromOSG, lookAtOSG, up);
     myViewer->home();
 }
 
@@ -433,7 +443,7 @@ GUIOSGView::showViewportEditor() {
 
 
 void
-GUIOSGView::setViewport(const Position& lookFrom, const Position& lookAt) {
+GUIOSGView::setViewportFromTo(const Position& lookFrom, const Position& lookAt) {
     osg::Vec3d lookFromOSG, lookAtOSG, up;
     myViewer->getCameraManipulator()->getHomePosition(lookFromOSG, lookAtOSG, up);
     lookFromOSG[0] = lookFrom.x();
@@ -447,6 +457,17 @@ GUIOSGView::setViewport(const Position& lookFrom, const Position& lookAt) {
 }
 
 
+
+void
+GUIOSGView::copyViewportTo(GUISUMOAbstractView* view) {
+    osg::Vec3d lookFrom, lookAt, up;
+    myCameraManipulator->getHomePosition(lookFrom, lookAt, up);
+    view->setViewportFromTo(Position(lookFrom[0], lookFrom[1], lookFrom[2]),
+                            Position(lookAt[0], lookAt[1], lookAt[2]));
+}
+
+
+
 void
 GUIOSGView::startTrack(int id) {
     if (myTracked == 0 || (int)myTracked->getGlID() != id) {
@@ -484,9 +505,9 @@ GUIOSGView::stopTrack() {
 }
 
 
-int
+GUIGlID
 GUIOSGView::getTrackedID() const {
-    return myTracked == 0 ? -1 : myTracked->getGlID();
+    return myTracked == 0 ? GUIGlObject::INVALID_ID : myTracked->getGlID();
 }
 
 
@@ -516,7 +537,7 @@ GUIOSGView::onGamingClick(Position pos) {
         const std::vector<MSTrafficLightLogic*> logics = vars.getAllLogics();
         if (logics.size() > 1) {
             MSSimpleTrafficLightLogic* l = (MSSimpleTrafficLightLogic*) logics[0];
-            for (unsigned int i = 0; i < logics.size() - 1; i++) {
+            for (int i = 0; i < (int)logics.size() - 1; i++) {
                 if (minTll->getProgramID() == logics[i]->getProgramID()) {
                     l = (MSSimpleTrafficLightLogic*) logics[i + 1];
                     tlsControl.switchTo(minTll->getID(), l->getProgramID());
