@@ -2,12 +2,12 @@
 /// @file    MFXEventQue.h
 /// @author  Daniel Krajzewicz
 /// @date    2004-03-19
-/// @version $Id: MFXEventQue.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MFXEventQue.h 21202 2016-07-19 13:40:35Z behrisch $
 ///
 // missing_desc
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -62,9 +62,9 @@ public:
         myMutex.unlock();
     }
 
-    size_t size() {
+    int size() {
         myMutex.lock();
-        const size_t ret = myItems.size();
+        const int ret = (int)myItems.size();
         myMutex.unlock();
         return ret;
     }
