@@ -5,7 +5,7 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Sept 2002
-/// @version $Id: GUIGlObject.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GUIGlObject.cpp 21851 2016-10-31 12:20:12Z behrisch $
 ///
 // Base class for all objects that may be displayed within the openGL-gui
 /****************************************************************************/
@@ -61,6 +61,8 @@ StringBijection<GUIGlObjectType>::Entry GUIGlObject::GUIGlObjectTypeNamesInitial
     {"lane",          GLO_LANE},
     {"junction",      GLO_JUNCTION},
     {"crossing",      GLO_CROSSING},
+    {"connection",    GLO_CONNECTION},
+    {"prohibition",   GLO_PROHIBITION},
     {"tlLogic",       GLO_TLLOGIC},
     {"detector",      GLO_DETECTOR},
     {"trigger",       GLO_TRIGGER},
@@ -75,6 +77,7 @@ StringBijection<GUIGlObjectType>::Entry GUIGlObject::GUIGlObjectTypeNamesInitial
 
 
 StringBijection<GUIGlObjectType> GUIGlObject::TypeNames(GUIGlObjectTypeNamesInitializer, GLO_MAX);
+const GUIGlID GUIGlObject::INVALID_ID = 0;
 
 // ===========================================================================
 // method definitions
@@ -155,7 +158,7 @@ void
 GUIGlObject::drawGLAdditional(GUISUMOAbstractView* const parent, const GUIVisualizationSettings& s) const {
     UNUSED_PARAMETER(&s);
     UNUSED_PARAMETER(parent);
-};
+}
 
 #ifdef HAVE_OSG
 
