@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: TrackerValueDesc.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: TrackerValueDesc.h 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // Representation of a timeline of floats with their names and moments
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -130,7 +130,7 @@ private:
     SUMOReal myInvalidValue;
 
     /// Counter for valid numbers within the current aggregation interval
-    size_t myValidNo;
+    int myValidNo;
 
     /// The time step the values are added from
     SUMOTime myRecordingBegin;
