@@ -3,12 +3,12 @@
 @file    route2trips.py
 @author  Jakob Erdmann
 @date    2015-08-05
-@version $Id: route2sel.py 18756 2015-08-31 19:16:33Z behrisch $
+@version $Id: route2sel.py 20433 2016-04-13 08:00:14Z behrisch $
 
 This script converts SUMO routes into an edge selection
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2008-2015 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2008-2016 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -17,6 +17,7 @@ the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
 from __future__ import print_function
+from __future__ import absolute_import
 import sys
 from optparse import OptionParser
 from sumolib.output import parse_fast
@@ -39,8 +40,21 @@ def parse_args():
 def main():
     options = parse_args()
     edges = set()
+
     for route in parse_fast(options.routefile, 'route', ['edges']):
         edges.update(route.edges.split())
+    for walk in parse_fast(options.routefile, 'walk', ['edges']):
+        edges.update(walk.edges.split())
+
+    # warn about potentially missing edges
+    for trip in parse_fast(options.routefile, 'trip', ['id', 'from', 'to']):
+        edges.update([trip.attr_from, trip.to])
+        print(
+            "Warning: Trip %s is not guaranteed to be connected within the extracted edges." % trip.id)
+    for walk in parse_fast(options.routefile, 'walk', ['from', 'to']):
+        edges.update([walk.attr_from, walk.to])
+        print("Warning: Walk from %s to %s is not guaranteed to be connected within the extracted edges." % (
+            walk.attr_from, walk.to))
 
     with open(options.outfile, 'w') as outf:
         for e in sorted(list(edges)):
