@@ -5,12 +5,12 @@
 @author  Karol Stosiek
 @author  Michael Behrisch
 @date    2011-11-28
-@version $Id: roundabout.py 18096 2015-03-17 09:50:59Z behrisch $
+@version $Id: roundabout.py 20637 2016-05-04 07:40:50Z luecken $
 
 This file contains a Python-representation of a single roundabout.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2008-2015 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2008-2016 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -22,8 +22,12 @@ the Free Software Foundation; either version 3 of the License, or
 
 class Roundabout:
 
-    def __init__(self, nodes):
+    def __init__(self, nodes, edges=None):
         self._nodes = nodes
+        self._edges = edges
 
     def getNodes(self):
         return self._nodes
+
+    def getEdges(self):
+        return self._edges
